# -*- coding: utf-8 -*-

"""Localize the unit handling."""

import pint

# Unit handling!
ureg = pint.UnitRegistry(auto_reduce_dimensions=True)
pint.set_application_registry(ureg)
Q_ = ureg.Quantity
units_class = ureg("1 km").__class__

_d = pint.Context("chemistry")

factor = ureg.mol / ureg.avogadro_number

_d.add_transformation("", "[substance]", lambda ureg, x: x * factor)
_d.add_transformation("[substance]", "", lambda ureg, x: x / factor)

_d.add_transformation("[mass]/[substance]", "[mass]", lambda ureg, x: x * factor)

_d.add_transformation(
    "[length] * [mass] / [substance] / [time] ** 2",
    "[length] * [mass] / [time] ** 2",
    lambda ureg, x: x * factor,
)
_d.add_transformation(
    "[length] * [mass] / [time] ** 2",
    "[length] * [mass] / [substance] / [time] ** 2",
    lambda ureg, x: x / factor,
)

_d.add_transformation(
    "[length] ** 2 * [mass] / [substance] / [time] ** 2",
    "[length] ** 2 * [mass] / [time] ** 2",
    lambda ureg, x: x * factor,
)
_d.add_transformation(
    "[length] ** 2 * [mass] / [time] ** 2",
    "[length] ** 2 * [mass] / [substance] / [time] ** 2",
    lambda ureg, x: x / factor,
)

ureg.add_context(_d)
ureg.enable_contexts("chemistry")


if __name__ == "__main__":  # pragma: no cover
    E = Q_(1.0, "kcal/mol")
    E2 = E.to("eV")
    print(f"{E:~} = {E2:~.4}")
    print()

    E2 = E.to("kJ/mol")
    print(f"{E:~} = {E2:~.4}")
    print()

    E = Q_(1.0, "eV")
    E2 = E.to("kcal/mol")
    print(f"{E:~} = {E2:~.4}")
    print()

    E2 = E.to("kJ/mol")
    print(f"{E:~} = {E2:~.4}")
    print()

    E = Q_(1.0, "mol")
    E2 = E.to("")
    print(f"{E:~} = {E2:~.4}")
    print()

    E = Q_(6.022e23, "")
    E2 = E.to("mol")
    print(f"{E:~} = {E2:~.4}")
    print()

    E = Q_(1, "kcal/mol/angstrom")
    E2 = E.to("eV/angstrom")
    print(f"{E:~} = {E2:~.4}")
    print()

    E = Q_(1, "eV/angstrom")
    E2 = E.to("kcal/mol/angstrom")
    print(f"{E:~} = {E2:~.4}")
    print()



# -*- coding: utf-8 -*-

"""
seamm_util
Utility functions for the SEAMM environment.
"""

# Bring up the classes so that they appear to be directly in
# the seamm_util package.

from seamm_util.argument_parser import getParser  # noqa: F401
from seamm_util.argument_parser import seamm_parser  # noqa: F401
from seamm_util.elemental_data import element_data  # noqa: F401
from seamm_util.check_executable import check_executable  # noqa: F401
from seamm_util.dictionary import Dictionary  # noqa: F401
from seamm_util.units import ureg, Q_, units_class  # noqa: F401
from seamm_util.include_open import Open  # noqa: F401
from seamm_util.include_open import splitext  # noqa: F401
from seamm_util.seamm_json import JSONDecoder  # noqa: F401
from seamm_util.seamm_json import JSONEncoder  # noqa: F401
from seamm_util.plotting import Figure  # noqa: F401
import seamm_util.printing  # noqa: F401
import seamm_util.variable_names  # noqa: F401
import seamm_util.water_models  # noqa: F401

# Handle versioneer
from ._version import get_versions

__author__ = """Paul Saxe"""
__email__ = "psaxe@molssi.org"
versions = get_versions()
__version__ = versions["version"]
__git_revision__ = versions["full-revisionid"]
del get_versions, versions
